# Paks

> Paks is a package manager optimized for community contributions and containers 📦️

## Goals

We want a package manager that is optimized to help people build packages from source,
and distribute the binaries via GitHub packages and also provide robust metadata
and an organization scheme that works well for containers. We want a focus on that
and then testing and automatically updating the individual packages provided.

🚧️ **under development** 🚧️

